pub struct StringWriter<W: Write> { /* private fields */ }Expand description
A writer that writes to an output implementing std::fmt::Write.
It’s wrapper of a basic writer with extra functionality.
Implementations
Sourceimpl<W: Write> StringWriter<W>
impl<W: Write> StringWriter<W>
pub fn new(writer: W) -> Self
Sourcepub fn output_byte_counter(&self) -> u64
pub fn output_byte_counter(&self) -> u64
Returns the number of bytes that have been written to the output.
Sourcepub fn captured_chars(&self) -> Vec<char>
pub fn captured_chars(&self) -> Vec<char>
Returns a copy of the bytes that have been written to the output.